#
# spec file for package python-sip
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define python_sip_api 11.2
Name:           python-sip
Version:        4.16.9
Release:        5.5
Summary:        SIP tool to use python sip bindings
License:        GPL-2.0 or GPL-3.0 or SUSE-SIP
Group:          Development/Libraries/Python
Url:            http://www.riverbankcomputing.com/software/sip/introa
Source0:        sip-%{version}.tar.gz
# PATCH-FIX-OPENSUSE disable-rpaths.diff -- Disable rpaths
Patch0:         disable-rpaths.diff
# PATCH-FIX-OPENSUSE build-compare.diff cmorve69@yahoo.es -- Fix build-compare
Patch1:         build-compare.diff
BuildRequires:  c++_compiler
BuildRequires:  python
BuildRequires:  python-devel
Provides:       python-sip(api) = %{python_sip_api}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%py_requires

%description
SIP is a tool that makes it very easy to create Python bindings for C
and C++ libraries. It was originally developed to create PyQt, the
Python bindings for the Qt toolkit, but can be used to create bindings
for any C or C++ library.

%package devel
Summary:        SIP tool to create python bindings
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
Requires:       c++_compiler
Requires:       python-devel
Requires(post): update-alternatives
Provides:       python-sip-bin = %{version}
Obsoletes:      python-sip-bin < %{version}

%description devel
SIP is a tool that makes it very easy to create Python bindings for C
and C++ libraries. It was originally developed to create PyQt, the
Python bindings for the Qt toolkit, but can be used to create bindings
for any C or C++ library.

This package contains all the developer tools you need to create your
own sip bindings.

%prep
%setup -q -n sip-%{version}
%patch0
%patch1

%build
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"
# Link against libpython (fixes bnc#756282 and bnc#721280)
python configure.py --debug CFLAGS+="%{optflags}" CXXFLAGS+="%{optflags}" LIBS+="-lpython%{py_ver}"
make %{?_smp_mflags}

sip_major=$(grep "define SIP_API_MAJOR_NR" siplib/sip.h.in | awk '{print $3}')
sip_minor=$(grep "define SIP_API_MINOR_NR" siplib/sip.h.in | awk '{print $3}')

if test "%{python_sip_api}" != "$sip_major.$sip_minor"; then
    echo "API version was changed to $sip_major.$sip_minor"
    exit 1
fi

echo "%%requires_python_sip_api Requires: python-sip(api) = $sip_major.$sip_minor" > macros.%{name}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
mkdir -p %{buildroot}%{_datadir}/sip

# For alternatives
mv %{buildroot}%{_bindir}/sip %{buildroot}%{_bindir}/sip-%{py_ver}
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
touch %{buildroot}%{_sysconfdir}/alternatives/sip
ln -s -f %{_sysconfdir}/alternatives/sip %{buildroot}/%{_bindir}/sip

install -m 644 -D macros.%{name} %{buildroot}/%{_sysconfdir}/rpm/macros.%{name}

# Point to the correct location for the documentation files
sed -i 's/"doc" directory/"doc" directory of package %{name}-devel/' README

%post devel
update-alternatives --install %{_bindir}/sip sip %{_bindir}/sip-%{py_ver} 50

%preun devel

if [ "$1" = 0 ] ; then
    update-alternatives --remove sip %{_bindir}/sip-%{py_ver}
fi

%files
%defattr(-,root,root,-)
%doc README
%{py_sitedir}/sip.so

%files devel
%defattr(-,root,root,-)
%doc NEWS LICENSE* doc/
%config %{_sysconfdir}/rpm/macros.%{name}
%{_bindir}/sip-%{py_ver}
%ghost %{_sysconfdir}/alternatives/sip
%{_bindir}/sip
%{py_incdir}/sip.h
%{py_sitedir}/sipconfig.py
%{py_sitedir}/sipdistutils.py
%{_datadir}/sip/

%changelog
* Mon Jul 20 2015 termim@gmail.com
- Update to 4.16.9:
  * This is mainly a bug-fix release.
* Sat Jun 13 2015 termim@gmail.com
- Update to 4.16.8:
  * This is mainly a bug-fix release.
- Update to 4.16.7:
  * This is a minor functional and bug-fix release.
- Update to 4.16.6:
  * Added the /FileExtension/ class annotation.
  * Installing into a virtual env should now work.
  * Timestamps are no longer included in generated code. The -T command
    line option is now ignored and deprecated.
  * The @file method of passing additional command line options is now
    supported. The -z command line option is now deprecated.
* Tue Dec 30 2014 hrvoje.senjan@gmail.com
- Update to 4.16.5:
  * Minor functional and bug-fix release.
  - Changes since 4.16.4:
  * Added the /AbortOnException/ function annotation.
  * Added the /DisallowNone/ function annotation.
  * Added the /DisallowNone/ argument annotation.
* Sat Oct 11 2014 termim@gmail.com
- Update to 4.16.3
  - This is a minor functional release including the implementation of
    __qualname__ for class enums.
  - run spec-cleaner
* Thu Jul 31 2014 toddrme2178@gmail.com
- Update to 4.16.2
  - Deprecated the %%ConsolidatedModule directive as it won't be supported in
    SIP v5.
  - Bug fixes.
* Tue Jun 10 2014 termim@gmail.com
- Update to 4.16.1
  - Bug fixes.
* Thu May 29 2014 termim@gmail.com
- Update to 4.16
  - Added the /NoSetter/ variable annotation.
  - Added the -B option to sip.
  - Changed the handling of timelines (introducing a potential incompatibility)
    so that later versions of wrapped libraries can be wrapped so long as they
    are compatible with known versions.
  - Added support for the 'no_receiver_check' argument to connect() in PyQt
    v4.11.
  - Added the --configuration option to configure.py.
  - Added the --sysroot option to configure.py.
  - Added the --target-py-version option to configure.py.
  - Added the --no-tools option to configure.py.
  - Added the --use-qmake option to configure.py.
  - Bug fixes.
* Mon Mar 17 2014 termim@gmail.com
- Update to 4.15.5
  - The use_arch argument of sipconfig.create_wrapper() can now specify a space
    separated set of architectures.
  - Bug fixes.
* Fri Jan 10 2014 lbeltrame@kde.org
- Fix SNAFU in preun scriptlet (missing spaces)
* Thu Jan  9 2014 lbeltrame@kde.org
- New upstream version 4.15.4:
  - Fixed all the compiler warning messages when building the sip module.
  - Fixed the parsing of C++ types involving multiple const and pointers.
  - Added SIP_SSIZE_T_FORMAT to the C API.
  - Moved the lexer and parser meta-source files to a separate directory to avoid
  problems with make accidentaly regenerating them.
  - Allow the pointers used to store the parsed results from Python
  reimplementations to be NULL.
  - Remove the __pycache__ directory when cleaning.
* Sun Oct 20 2013 lbeltrame@kde.org
- Use alternatives for /usr/bin/sip to prevent conflicts between
  Python 3 and Python 2 python-sip-devel packages
* Thu Oct 17 2013 toddrme2178@gmail.com
- update to v4.15.3. This is a bug fix release for a regression
  that affects PyQtChart.
* Thu Sep 19 2013 toddrme2178@gmail.com
- update to v4.15.2. This is a minor functional release that will
  be needed by PyQt v5.1. It also contains bug fixes needed by
  PyKDE4.
* Tue Sep 17 2013 speilicke@suse.com
- Revert sr#79987, moving /usr/bin/sip into python-sip-bin and requiring
  that in python3-sip-devel (plus split provides) only causes trouble. It will
  make python3-sip-devel depend forever on Python2 for absolutely no reason.
  Both python-sip-devel and python3-sip-devel can happily provide /usr/bin/sip
  since the binary is identical. You can have both installed in parallel and
  remove either without breaking anything. (bnc#835161)
* Wed Sep 11 2013 tittiatcoke@gmail.com
- Build issues are resolved with the Python KDE bindings. Return
  to version 4.15.1
* Fri Aug 30 2013 tittiatcoke@gmail.com
- Revert back to version 4,14,7 to prevent crashes in Plasma-desktop
  (bko#323899).
* Tue Aug 27 2013 termim@gmail.com
-  update to 4.15.1. This fixes a regression in v4.15 related to the handling of hidden virtual methods. The regression does not affect PyQt.
-  update to v4.15. This is a significant functional release and required by PyQt v5.0.1 and PyQt v4.10.3.
  - Added the call_super_init argument to the %%Module directive to specify that classes should support cooperative multi-inheritance.
  - Added the %%FinalisationCode directive.
  - Added the /Mixin/ class annotation.
  - Added the /NoScope/ enum annotation.
  - Added sipConvertFromNewPyType() to the C API.
  - Added sipConvertToArray() and sipConvertToTypedArray() to the C API.
  - Added sipRegisterProxyResolver() to the C API.
* Wed Jun 19 2013 dmueller@suse.com
- update to 4.14.7:
  - The internal API version is increased to 10.0 requiring the regeneration of
    all modules.
  - Added the /Sequence/ function annotation.
  - %%ConvertFromTypeCode can now be specified for classes.
  - Added sipEnableAutoconversion() to the C API.
  - Added sipSetDestroyOnExit() to the C API.
  - Bug fixes.
* Mon Apr 22 2013 dmueller@suse.com
- update to 4.14.6:
  * Bug fix
* Wed Mar 27 2013 dmueller@suse.com
- update to 4.14.5 (bnc#812130):
  * Bug fixes (specifically for QGIS)
* Thu Mar  7 2013 mlin@suse.com
- Update to 4.14.4
  * bugfix release
  * include a potential incompatibility in the use of the %%VirtualErrorHandler directive.
* Tue Jan 29 2013 dmueller@suse.com
- update to 4.14.3:
  - The /KeepReference/ argument annotation, when applied to factories, will
    now keep the reference with the object created by the factory.
  - Any object that supports the buffer protocol can now be passed when a
    sip.voidptr is expected.
* Sun Dec  9 2012 lbeltrame@kde.org
- Update to 4.14.2:
  - Added sip.setdestroyonexit().
  - sip.voidptr() will now accept any object that implements the buffer
    protocol.
* Mon Oct 29 2012 dmueller@suse.com
- update to 4.14.1:
  - SIP_PYBUFFER can now be used to define objects that implement the Python
    buffer protocol.
  - Added /Capsule/ typedef annotation.
  - Added the 'z' format character to sipBuildResult().
  - Added the 'z', '!' and '$' format characters to sipParseResult().
  - The C prototype foo(void) is now accepted.
  - sipdistutils.py will now include swig_opts if no sip_opts have been
    defined.
  - Bug fixes.
* Mon Oct  1 2012 einar@heavensinferno.net
- Update to latest upstream version:
  - The internal API version is increased to 9.0 requiring the regeneration
    of all modules.
  - Added the %%InstanceCode directive.
  - Added the %%VirtualErrorHandler directive.
  - Added the default_VirtualErrorHandler argument to the %%Module directive.
  - Added the VirtualErrorHandler class annotation.
  - Added the NoVirtualErrorHandler and VirtualErrorHandler function
    annotations.
  - The AllowNone and NoRelease mapped type annotations can now be used
    with mapped type templates.
  - SIP_PLATFORM_* and SIP_TIMELINE_* preprocessor symbols are generated
    corresponding to the -t arguments passed on the command line.
  - Deprecated sipTransferBreak().
  - For Python v2.x unsigned short and unsigned char (when used as a byte)
    are now converted to int, rather than long, objects.
  - Added support for MSVC 2010 to the build system.
-
* Thu Jul  5 2012 dmueller@suse.com
- install api version as rpm macro
* Fri Jun 22 2012 mlin@suse.com
- Update to version 4.13.3
  * The /NoRaisesPyException/ and /RaisesPyException/ function annotations can
    now be applied to constructors.
  * Added support for the Python v3.3 handling of Unicode.
* Tue Apr 10 2012 asterios.dramis@gmail.com
- Link against libpython. Fixes bnc#756282 and bnc#721280.
- Remove SUSE_ASNEEDED=0 from spec file.
* Fri Mar 23 2012 cfarrell@suse.com
- license update: GPL-2.0 or GPL-3.0 or SUSE-SIP
  Use SUSE- proprietary extension until SIP license is accepted upstream at
  spdx.org
* Mon Feb 20 2012 dmueller@suse.de
  update to 4.13.2:
  - A bug fix release.
* Fri Dec 23 2011 dmueller@suse.de
- update to 4.13.1:
  - Deprecation warnings can no longer be disabled.
  - Added the all_raise_py_exception argument to the %%Module directive.
  - Added the /NoRaisesPyException/ function annotation.
  - Added the /PyName/ typedef annotation.
  - Class templates now allow super-classes to be defined as template
  arguments.
  - Added support for 'public' preceding the name of a class in a super-class
  list.
  - Added support for 'protected' and 'private' preceding the name of a class
  in a super-class list.  Any such super-class will be ignored.
* Thu Oct 27 2011 Sascha.Manns@open-slx.de
- Changelog from the Creators
  - SIP v4.13 has been released. This is a minor feature release.
    o added the %%DefaultDocstringFormat directive
    o added the format argument to the %%Docstring directive
    o %%ConvertToSubClassCode can now cause a restart of the conversion
    process using a different requested type
    o '*' and '&' are now supported as unary operators in expressions
    used in the values of default arguments
    o the /Transfer/ annotation can now be used with the /Array/
    annotation to prevent the freeing of the temporary array of
    pointers.
* Wed Oct 26 2011 Sascha.Manns@open-slx.de
- Updated to 4.13
  - last stable release
* Mon Aug 29 2011 termim@gmail.com
- Add python-sip-bin package to avoid conflicts between python2
  and python3 versions
* Tue Aug 16 2011 termim@gmail.com
- Update to 4.12.4
  - A bug fix release.
* Mon May 30 2011 dmueller@suse.de
- update to 4.12.3:
  - A bug fix release.
* Mon May  2 2011 dmueller@suse.de
- update to 4.12.2:
  * /KeepReference/ is now supported as a function annotation.
  * Handwritten code in class templates no longer have the types
  substituted in lines that appear to contain C preprocessor directives.
  * Added support for global inplace numeric operators.
* Tue Jan 25 2011 dmueller@suse.de
- update to 4.12.1:
  - Added support for the __getattribute__, __getattr__, __setattr__ and
    __delattr__ methods.
  - Added the /RaisesPyException/ function annotation.
  - Added SIP_SSIZE_T as a predefined type.
  - PyObject * can now be used as a synonym for SIP_PYOBJECT.
  - Added sip.ispycreated() to the sip module.
  - Added the --deployment-target flag to configure.py for MacOS/X.
* Mon Dec 27 2010 dmueller@suse.de
- update to 4.12:
  - Implemented the revised directive syntax for %%Module.
  - Deprecated %%CModule, use %%Module instead.
  - Added the keyword_arguments argument to %%Module to specify the level of
    support for Python keyword arguments.
  - Deprecated the -k flag to sip, use the keyword_arguments argument to
    %%Module instead.
  - Added an automatic pseudo-%%Timeline to allow the SIP version number to be
    used in the %%If directive.
  - Changed the behavior of the /KeywordArgs/ annotation to specify the level
    of support for Python keyword arguments.
  - Deprecated the /NoKeywordArgs/ annotation, use /KeywordArgs="All"/ instead.
  - Added the use_argument_names argument to %%Module to provide the real names
    of arguments to handwritten code.
  - Module docstrings are now supported.
  - Added %%AutoPyName to automatically provide Python names.
  - Added %%Property to implement Python properties based on C/C++ getters and
    setters.
  - Added %%Extract to allow arbitrary text to be embedded in specification
    files and subsequently extracted.
  - Deprecated %%Doc and %%ExportedDoc, use %%Extract instead.
  - Added the -X flag to sip to extract text defined with %%Extract.
  - Deprecated the -d flag to sip, use -X instead.
  - Added /PyInt/ as an argument, function and typedef annotation to force
    char types to be handled as Python integers rather that single character
    strings.
  - Added the L and M format characters to sipBuildResult(), sipCallMethod()
    and sipParseResult().
  - Added sipGetAddress().
  - Added the -T flag to sip to suppress the timestamp in the header comments
    of generated files.
  - sip.voidptr now behaves like a Python memoryview object and supports
    sub-script assignment.
  - Added the --sip-module flag to configure.py to allow the name and
    containing package of the sip module to be specified thereby allowing
    packages to include a local copy of the sip module.
* Mon Oct 25 2010 dmueller@suse.de
- update to 4.11.2:
  - /KeepReference/ can now be applied to global functions and static methods.
  - %%TypeCode can now be specified in a %%MappedType directive.
  - Mapped types for templates no longer require the template arguments to be
    fully defined.
  - Build system changes required by PyQt v4.8 and Qt v4.7.
* Fri Oct  1 2010 einar@heavensinferno.net
- update to 4.11.1:
  - A bug fix release.
* Mon Sep  6 2010 coolo@novell.com
- fix python linking for factory
* Wed Sep  1 2010 dmueller@suse.de
- update to 4.11:
  - Added the %%UnitPostIncludeCode directive.
  - /KeepReference/ will now accept a key to track when the same object is
    passed to more than one method.
  - operator() and __call__() can now accept keyword arguments.
  - Added support for Python v3.2.
* Mon Aug 16 2010 dmueller@suse.de
- update to 4.10.5:
  - A bug fix release for Python v3 and Python v2.7.
  - Use capsules when being built for Python v2.7 to work around an apparent
    bug in the support for PyCObject.
  - Added support for Q_SLOT, Q_SLOTS, Q_SIGNAL and Q_SIGNALS.
  - Added the /__len__/ function annotation.
* Tue Jun  8 2010 dmueller@suse.de
- update to 4.10.2:
  - A bug fix release.
* Wed May 19 2010 cmorve69@yahoo.es
- fix build-compare
* Fri Mar 26 2010 dmueller@suse.de
- update to 4.10.1:
  * Added the /NoCopy/ function and argument annotations.
* Fri Jan 15 2010 tittiatcoke@gmail.com
- update to 4.10
  * Added the sip.voidptr.ascapsule() method.
  * Added the -P command line option to build modules with
    "protected" redefined to "public" if supported by the platform.
    This can result in significantly smaller modules.
  * Added the -o command line option to automatically generate docstrings.
  * Added the -k command line option and /KeywordArgs/ and /NoKeywordArgs/
    function annotations to support keyword arguments.
  * Added the /Default/ exception annotation.
  * Added the /DocType/ argument, function, mapped type and variable annotations.
  * Added the /DocValue/ argument annotation.
  * Added the %%Docstring directive to specify explicit docstrings for classes,
    functions and methods.
  * Added sipError to %%MethodCode to allow user errors to be distinguished
    from interpreter errors.
  * Added sipBadCallableArg() to the C API.
  * Added support for configuring and building outside of the source tree.
* Tue Nov 24 2009 hpj@urpla.net
- update to 4.9.3:
  * A bug fix release.
* Fri Nov 20 2009 dmueller@suse.de
- update to 4.9.2:
  * A bug fix release.
* Fri Nov 20 2009 dmueller@suse.de
- add split-provides
* Sat Oct 24 2009 dmueller@suse.de
- update to 4.9.1:
  * A bug fix release.
* Mon Sep 28 2009 dmueller@suse.de
- update to 4.9:
  * support for __iter__ and __next__
  * the %%API directive
  * the /API/ annotation
  * sipIsAPIEnabled() has been added to the C API
  * sip.getapi() and sip.setapi() have been added to the Python API
  * sip.ispyowned() has been added to the Python API
  * mapped types can now act as a namespace for enums and static methods
  * the /Array/ annotation can now be applied to classes and mapped types
  * the /NoArgParser/ annotation can now be applied to methods as well as functions
  * the --arch flag was added to configure.py to specify which MacOS/X architectures are built
  * SIP is now also licensed under the GPL v2 and v3.
* Mon Aug 31 2009 beineri@opensuse.org
- fix plasmoids requiring python-devel to work (part of bnc#535057)
* Tue Aug  4 2009 hpj@urpla.net
- Fixed a crash with sipFindType() when the search happens to land on an
  unresolved external type.
* Thu Jul 30 2009 hpj@urpla.net
- update to 4.8.2:
  - Fixed the '/' operator for Python v3 and future import for Python v2.
  - Backported the /AllowNone/ class annotation from v4.9.
* Mon Jul  6 2009 hpj@urpla.net
- create a separated -devel package and include the nice documentation
* Wed Jun 17 2009 dmueller@suse.de
- update to 4.8.1:
  - Added support for defining a private assignment operator to suppress the
  possible generation of an assignment helper.
* Mon Jun  8 2009 beineri@opensuse.org
- update to 4.8 release:
  * support for Python v3
  * the ability to supply alternate super-types and meta-types
    for wrapped objects
  * documentation built using Sphinx
* Tue Jun  2 2009 dmueller@suse.de
- update to 20090601 snapshot fixing nested template handling
* Sun May 17 2009 beineri@opensuse.org
- update to 4.8 snapshot as of 20090430
* Fri Dec  5 2008 dmueller@suse.de
- update to 4.7.9:
  - Added the /Deprecated/ class and function annotation (based on a patch from
    Lorenzo Berni).
  - Templates now support instance variables and enums.
  - A Python int object can now be used whenever an enum is expected without
    needing to explicitly cast it using the enum's constructor.  The
    /Constrained/ argument annotation can be used to suppress this behaviour.
  - typedef type names are now used in string representations of types (e.g. in
    the names of mapped types) to reflect what the programmer sees rather than
    what the compiler sees.  The /NoTypeName/ typedef annotation can be used to
    suppress this behaviour.
  - The new handling of the typedef names was correctly using the real types for
    virtual handler arguments but not the return values.
* Sun Aug 10 2008 dmueller@suse.de
- update to 4.7.7:
  * C++ structs are now properly handled as a class with
  a default public  section
  * sip.dump() now includes the objects first child wrapper
* Tue May 27 2008 dmueller@suse.de
- update to 4.7.6:
  * generator fixes for being able to bind Qt 4.4
* Wed Feb 13 2008 dmueller@suse.de
- update to 4.7.4:
  * The build system handles the directory structure used by Leopard's Python
    installation.
  * Added support for /Transfer/ as a constructor ann
* Thu Dec 13 2007 dmueller@suse.de
- update to 4.7.3:
  * Added support for automatically generating missing complementary
    comparision operators.  Note that this introduces a potential compatibility
    problem - see the documentation for details.
  * Added the SingleShot argument annotation.
  * Added the TransferThis function annotation.
* Mon Oct  1 2007 stbinner@suse.de
- update to 4.7.1: minor bugfixes
* Fri Aug 17 2007 dmueller@suse.de
- remove conflict as it is now common base for qt 3.x
  and qt 4.x (#300041)
* Sun Aug 12 2007 dmueller@suse.de
- %%py_requires no longer has buildrequires
* Sat Aug 11 2007 dmueller@suse.de
- add conflict against python-qt 3.x versions
* Thu Aug  2 2007 dmueller@suse.de
- update to 4.7:
  * Added %%PickleCode to allow handwritten code to pickle a wrapped C++
    instance or C structure.
  * Added %%CompositeModule to create modules that are composites of ordinary
    modules.
  * Added %%ConsolidatedModule (and the -p command line option) to create
    modules that contain all the wrapper code on behalf of ordinary modules.
  * Added the dump() function to the sip module.
  * Added sipTransferBreak() to the SIP API.
  * Added support for /Transfer/ as a function annotation.
* Wed Apr 11 2007 dmueller@suse.de
- update to 4.6:
  * Added support for wchar_t.
  * The -g command line option releases the GIL whenever a call is made to the
  * wrapped library.
  * Added the /HoldGIL/ annotation to explicitly retain the GIL when calling a
    particular function in the wrapped library.
  * Added sipFindClass() and sipFindNamedEnum() to the public API.
  * /TransferThis/ may be specified more than once.
  * Added support for __truediv__ and __itruediv__.
* Fri Jan 26 2007 dmueller@suse.de
- Initial package (4.5.2)
